%% script for computing the first Lyapunov exponent as in the paper "Couping the Yoccoz-Birkeland population model with price dynamics: chaotic livestock commodities market cycles" by Sylvain Arlot, Stefano Marmi and Duccio Papini (2018--2019)
%% assumes computations for model SP have been made previously (with ArMaPa18.m)
%% requires functions Wolf_Lyapunov_basgen.m, Wolf_Lyapunov_fet.m and Wolf_Lyapunov_search.m (straightforward adaptations from the matlab package "Estimating the dominant Lyapunov exponent from a Time Series" by Wolf, see README.txt for a web link)

%%% directory where the results / figures files should be stored/loaded
path_to_files='tmp/';

%%% number of years considered for estimating the first Lyapunov exponent
window_for_Lyapunov=100000;

%%% Load previously-made computations for setting SP

seed=7;% random seed used for generating the initial conditions
str_expe='HH';%% Note: 'HH' corresponds to the setting called 'SP' in the paper
current_dir=path_to_files; 
one_expe_modelBY;
options.window_long=10000;
options.Tmax=300000;
options.Tmin=max(0,options.Tmax-max(120,max(options.window_long,options.window_short)));

tmp_file_name=[path_to_files 'modelBY_' str_expe '_seed' num2str(seed)];
load([tmp_file_name '_output.mat'],'output');
load([tmp_file_name '_output_int.mat'],'output_int');

%%% Lyapunov exponent for (Nr(t) / t integer between 200000 and 300000)
    data=output_int.Nr(end-window_for_Lyapunov:end);
    tau = 1;%time delay for reconstructing the attractor in ndim dimensions
    ndim = 3;%the dimension of the delay reconstructed attractor
    ires = 10;%leave this at 10. the points of the time series, when delay reconstructed in ndim dimensions, will be placed in 10^ndim boxes. (Empty boxes require no memory storage.)
    maxbox = 6000;%leave this at 6000. unless the attractor is high dimensional, 6000 non-empty boxes are likely to be adequate.
db = Wolf_Lyapunov_basgen(data, tau, ndim, ires, maxbox);

    dt = 1;%time in seconds between time series samples
    evolve = 20;%time (in # of samples) to propagate a pair of points (from fiducial trajectory and an optimal nearest neighbor) before testing to see if the neighbor needs to be replaced.
    dismin = 0.001;%minimum separation between fiducial data point and new nearest neighbor (choose a value above the noise level). a relative (%) value -- scaled to the data set.
    dismax = 0.3;%maximum separation between fiducial data point and current nearest neighbor before replacement is permitted. also a relative value -- scaled to the data set.
    thmax = 30;%permissible angular error upon replacement of current nearest neighbor, in degrees.
filename_start=[path_to_files 'Lyapunov_Nr_int__']; 
    [out, SUM] = Wolf_Lyapunov_fet(db, dt, evolve, dismin, dismax, thmax,filename_start);
%    Wolf_Lyapunov_makeplot(db, out, evolve, 'NorthWest')

%%% Lyapunov exponent for (P(t) / t integer between 200000 and 300000)
    data=output_int.P(end-window_for_Lyapunov:end);
    tau = 1;%time delay for reconstructing the attractor in ndim dimensions
    ndim = 3;%the dimension of the delay reconstructed attractor
    ires = 10;%leave this at 10. the points of the time series, when delay reconstructed in ndim dimensions, will be placed in 10^ndim boxes. (Empty boxes require no memory storage.)
    maxbox = 6000;%leave this at 6000. unless the attractor is high dimensional, 6000 non-empty boxes are likely to be adequate.
db = Wolf_Lyapunov_basgen(data, tau, ndim, ires, maxbox);

    dt = 1;%time in seconds between time series samples
    evolve = 20;%time (in # of samples) to propagate a pair of points (from fiducial trajectory and an optimal nearest neighbor) before testing to see if the neighbor needs to be replaced.
    dismin = 0.001;%minimum separation between fiducial data point and new nearest neighbor (choose a value above the noise level). a relative (%) value -- scaled to the data set.
    dismax = 0.3;%maximum separation between fiducial data point and current nearest neighbor before replacement is permitted. also a relative value -- scaled to the data set.
    thmax = 30;%permissible angular error upon replacement of current nearest neighbor, in degrees.
filename_start=[path_to_files 'Lyapunov_P_int__']; 
    [out, SUM] = Wolf_Lyapunov_fet(db, dt, evolve, dismin, dismax, thmax,filename_start);
%    Wolf_Lyapunov_makeplot(db, out, evolve, 'NorthWest')



