function z=R_logistic(P,R_param)
% This function computes the proportion R(P) of newborn females that are put in the reproducting line at time t given the current price is P=P(t), with parameters given by R_param
% INPUTS: 
%	P: (vector of) price(s) [normalized]
%	R_param: structure containing parameters
%		R_param.R0: (minimal) value of R, attained for P=0 (between 0 and 1)
%		R_param.P_thresh: threshold price at which R' is maximal
%		R_param.R_degree: integer >= 2, such that R is proportional to P^{R_degree} for P below P_thresh
% OUTPUT: 
%	z: (vector of) the R(P)=R0+(1-R0)*f(P/P_thresh) with f(0)=0, f(Inf)=1, f increasing fastly around 1
%
%R_degree=2  => f(P)=(0.5*P.^2).*(P<1)+(1./(1+exp(-4*(P-1))).*(P>=1));
%R_degree>=2 => f(P)=(0.5*P.^(R_degree)).*(P<1)+(1./(1+exp(-(2*R_degree)*(P-1))).*(P>=1));

%f(P/P_thresh)=( (0.5*(P/(R_param.P_thresh)).^(R_param.R_degree)).*(P<(R_param.P_thresh)) + ( 1./(1+exp(-(2*R_param.R_degree)*( (P/(R_param.P_thresh))-1) ) ) ).*(P>=(R_param.P_thresh)) )

%z=R_param.R0+(1-R_param.R0)*((0.5*(P/(R_param.P_thresh)).^2).*(P<(R_param.P_thresh))+(1./(1+exp(-4*((P/(R_param.P_thresh)-1)))).*(P>=(R_param.P_thresh))));

z=R_param.R0+(1-R_param.R0)*( (0.5*(P/(R_param.P_thresh)).^(R_param.R_degree)).*(P<(R_param.P_thresh)) + ( 1./(1+exp(-(2*R_param.R_degree)*( (P/(R_param.P_thresh))-1) ) ) ).*(P>=(R_param.P_thresh)) );

