function entropy_vect=entropy_binary(eps_vect,kmax)
%%% combinatorial entropy of a binary time series (eps_vect), considering sequences of length k>0
%%% INPUT:
%%% 	eps_vect: time series (vector of size n), with values 0/1
%%%	kmax: positive integer
%%%
%%% OUTPUT:
%%%	entropy_vect: vector of size kmax, 
%%%		such that its k-th element is equal to -\sum_{length(s)=k} \mu(s,Y) ln_2 \mu(s,Y)
%%%		where the sum goes over all sequences of +/-1 of length k
%%%		and mu(s,Y) = proportion of subsequences of Y of length k that are equal to s


%%% preliminary transformation of eps_vect into a series of decimal numbers (corresponding to subsequences of length k, with a binary coding)

Z=eps_vect(kmax:end);
for k=1:(kmax-1)
	Z=Z+(2^(-k))*eps_vect(kmax-k:end-k);
end

entropy_vect=zeros(1,kmax);
%
for k=1:kmax
	%%% counts at the scale k
	edges=(0:2^(k)-1)/(2^(k-1));
	p_vect=histc(Z,edges)/numel(Z);
	%%% compute the corresponding entropy
	entropy_vect(k)=-sum(p_vect(p_vect>0).*log(p_vect(p_vect>0)))/log(2);
end

