function [slope,intercept,corr_coeff,residuals]=linreg(X,Y)
%%% least-squares linear regression of Y vs. X
%%% INPUT:
%%% 	X: vector of size n
%%%	Y: vector of size n
%%%
%%% OUTPUT:
%%%	slope: real number
%%%	intercept: real number
%%%		such that slope*X+intercept is the best linear approximation of Y given X with respect to the least-squares risk
%%%	corr_coeff: real number (correlation coefficient): the closer to 1 it is, the better is the fit
%%%	residuals: real number, equal to least-squares residuals, normalized by ???

Xbar=mean(X);
Ybar=mean(Y);


varX=sum((X-Xbar).^2);
if varX==0
	fprintf('Error in linreg.m: X is constant!\n');
	exit 11;
end

slope=sum((X-Xbar).*(Y-Ybar))/varX;
intercept=Ybar-slope*Xbar;

corr_coeff=(sum((X-Xbar).*(Y-Ybar))^2)/(varX*sum((Y-Ybar).^2));
residuals=mean((Y-X*slope-intercept).^2);

